import { BaseConnection, BaseCredential, BaseEntity, BaseProperty, BaseRecord, CredentialUpdateInput, CredentialWithConnection, FilterObject, MastraEngine } from '.';
export declare class MockEngine extends MastraEngine {
    constructor(config: {
        url: string;
    });
    close(): Promise<void>;
    getConnection({ connectionId, name, }: {
        name: string;
        connectionId: string;
    }): Promise<BaseConnection>;
    getConnectionById({ kId, }: {
        kId: string;
    }): Promise<BaseConnection | undefined>;
    getAllConnections(): Promise<Pick<BaseConnection, 'name' | 'connectionId'>[]>;
    getConnectionsByIntegrationName({ name, }: {
        name: string;
    }): Promise<BaseConnection[]>;
    getConnectionsBySubscriptionId({ subscriptionId, }: {
        subscriptionId: string;
    }): Promise<BaseConnection[]>;
    setConnectionSubscriptionId({ kId, subscriptionId, }: {
        kId: string;
        subscriptionId: string;
    }): Promise<BaseConnection>;
    createConnection({ connection, credential, }: {
        connection: any;
        credential: any;
    }): Promise<BaseConnection & {
        credential: BaseCredential;
    }>;
    setConnectionError({ kId, error, }: {
        kId: string;
        error: string;
    }): Promise<BaseConnection>;
    deleteConnection({ kId, }: {
        kId: string;
    }): Promise<BaseConnection | null>;
    getCredentialsByConnection(kId: string): Promise<CredentialWithConnection>;
    updateConnectionCredentialToken({ kId, token, }: {
        kId: string;
        token: Record<string, any>;
    }): Promise<BaseCredential>;
    updateConnectionCredentials(params: CredentialUpdateInput & {
        kId: string;
    }): Promise<BaseCredential>;
    syncData(params: {
        connectionId: string;
        name: string;
        data: any;
        type: string;
        properties: BaseProperty[];
        lastSyncId?: string;
    }): Promise<void>;
    buildRecordQuerySql(params: {
        whereClause: string;
        filterClause?: string;
        entityType: string;
        sortClauses: string[];
    }): string;
    getFilteredRecords<T extends string | number | symbol>(params: {
        entityType: string;
        filters?: FilterObject<T>;
        sort?: string[];
        kId: string;
    }): Promise<any[]>;
    getRecords<T extends string | number | symbol>(params: {
        entityType: string;
        kId: string;
        filters?: FilterObject<T>;
        sort?: string[];
    }): Promise<any[]>;
    createEntity(params: any): Promise<any>;
    getEntityById(params: {
        id: string;
    }): Promise<BaseEntity>;
    getEntityByConnectionAndType(params: {
        kId: string;
        type: string;
    }): Promise<BaseEntity | null>;
    getEntityRecordsByConnectionAndType(params: {
        kId: string;
        type: string;
    }): Promise<(BaseEntity & {
        properties: BaseProperty[];
        records: BaseRecord[];
    }) | null>;
    getEntitiesByConnection(connectionId: string): Promise<any[]>;
    getEntities(): Promise<any[]>;
    deleteEntity(id: string): Promise<any>;
    createEntityRecord(params: any): Promise<any>;
    getEntityRecordById(id: string): Promise<any>;
    deleteEntityRecord(id: string): Promise<any>;
    getEntityRecords(entityId: string): Promise<any[]>;
    updateEntityRecord(params: any): Promise<any>;
    getEntityProperties(entityId: string): Promise<any[]>;
    updateEntityLastSyncId(params: {
        id: string;
        syncId: string;
    }): Promise<BaseEntity>;
    deleteEntityById(params: {
        id: string;
    }): Promise<BaseEntity>;
    mergeExternalRecordsForEntity(params: {
        entityId: string;
        records: BaseRecord[];
    }): Promise<void>;
    getRecordsByPropertyName(params: {
        propertyName: string;
        connectionId: string;
    }): Promise<{
        record: BaseRecord;
    }[]>;
    getRecordByPropertyNameAndValue(params: {
        propertyName: string;
        propertyValue: string;
        type: string;
        connectionId: string;
    }): Promise<BaseRecord | null>;
    getRecordByPropertyNameAndValues(params: {
        propertyName: string;
        propertyValues: string[];
        type?: string;
        connectionId: string;
    }): Promise<{
        record: BaseRecord;
    }[]>;
    deleteRecordsByEntityId(params: {
        id: string;
    }): Promise<BaseRecord[]>;
    addPropertiesToEntity(params: {
        entityId: string;
        properties: BaseProperty[];
    }): Promise<BaseEntity>;
    getPropertiesByEntityType(params: {
        entityType: string;
    }): Promise<BaseProperty[]>;
    deletePropertiesByEntityId(params: {
        id: string;
    }): Promise<BaseProperty[]>;
}
